Changelog
=========

| *Version 1.0.0*: Adding a module with application functions for the calculation of the IBP index as well as the graphical visualization.
| *Version 1.0.1*: Create Sphinx documentation.
| *Version 1.0.2*: Rebuild package structure.
| *Version 1.0.3*: Integration into Read the Docs (https://ibp-model.readthedocs.io)
| *Version 1.0.4*: Move from https://test.pypi.org to https://pypi.org
| *Version 1.1.0*: Update of the coefficient file (SW_OPER_IBP_CLI_2__00000000T000000_99999999T999999_0002.cdf)
| *Version 1.1.1*: Correction at Sphinx setting
| *Version 1.1.2*: Change package init settings